@@ -8,9 +8,12 @@ stactools.core.use_fsspec()
 def register_plugin(registry: 'Registry') -> None:
     # Register subcommands
 
-    from stactools.cli.commands import (add, copy, info, layout, merge, create,
-                                        version, validate)
+    from stactools.cli.commands import (add, addraster, copy, create, info,
+                                        layout, merge, migrate, version,
+                                        validate)
 
+    registry.register_subcommand(add.create_add_command)
+    registry.register_subcommand(addraster.create_addraster_command)
     registry.register_subcommand(copy.create_copy_command)
     registry.register_subcommand(create.create_create_item_command)
     registry.register_subcommand(copy.create_move_assets_command)
@@ -20,7 +23,6 @@ def register_plugin(registry: 'Registry') -> None:
     registry.register_subcommand(merge.create_merge_command)
     registry.register_subcommand(validate.create_validate_command)
     registry.register_subcommand(version.create_version_command)
-    registry.register_subcommand(add.create_add_command)
 
     # TODO
     # registry.register_subcommand(migrate.create_migrate_command)
